package gonganxitong

import (
	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/ctx"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong/model"
)

const (
	EVENT_PLACE_CREATE = "web.team.community.place.create"
	EVENT_PLACE_REMOVE = "web.team.community.place.remove"
)

type portal struct {
	ice.Hash
	user        user
	userPlace   userPlace
	place       place
	export      string `data:"true"`
	short       string `data:"index"`
	field       string `data:"time,name,icons,index,order,enable"`
	list        string `name:"list place_uid index uid auto" role:"void"`
	placeCreate string `name:"placeCreate street_uid* address*" role:"void"`
	placeRemove string `name:"placeRemove place_uid*" role:"void"`
}

func (s portal) Inputs(m *ice.Message, arg ...string) {
	s.place.Inputs(m, arg...)
}
func (s portal) List(m *ice.Message, arg ...string) {
	if len(arg) == 0 {
		m.Cmdy(s.userPlace, s.userPlace.MyPlace, s.user.UserUID(m)).Action(s.PlaceCreate).PushAction(s.PlaceRemove)
		kit.If(m.Length() == 0, func() { m.EchoInfoButton(m.Trans("Please Create Your Place", "请添加场所"), s.PlaceCreate) })
	} else if len(arg) == 1 {
		s.Hash.List(m, arg[1:]...).SortInt(mdb.ORDER)
	} else if len(arg) == 2 {
		m.Cmdy(ctx.COMMAND, arg[1]).Push(ctx.ARGS, arg[0])
	} else {
		m.FieldsSetDetail().Cmdy(arg[1], mdb.SELECT, model.UID, arg[2]).PushAction().Action()
	}
	m.Display("").DisplayCSS("")
}
func (s portal) PlaceCreate(m *ice.Message, arg ...string) {
	m.ToastProcess()
	msg := m.Cmd(s.place, s.place.Select, model.UID, m.Option(model.STREET_UID))
	if !m.WarnNotFound(msg.Length() == 0, "street") {
		if !m.Cmdy(s.place, s.place.Create, arg).IsErr() {
			args := kit.Simple(model.USER_UID, s.user.UserUID(m), model.PLACE_UID, m.Result())
			m.Cmdy(s.userPlace, s.userPlace.Create, args)
			m.Event(EVENT_PLACE_CREATE, args, model.PLACE_ADDRESS, m.Option(model.ADDRESS))
			m.ProcessRefresh().ToastSuccess()
		}
	}
}
func (s portal) PlaceRemove(m *ice.Message, arg ...string) {
	m.ToastProcess()
	args := kit.Simple(model.USER_UID, s.user.UserUID(m), model.PLACE_UID, m.Option(model.PLACE_UID))
	msg := m.Cmd(s.userPlace, s.userPlace.Select, args)
	if !m.WarnNotFound(msg.Length() == 0, "place") {
		m.Cmdy(s.userPlace, s.userPlace.Delete, args)
		m.Cmdy(s.place, s.place.Delete, model.UID, m.Option(model.PLACE_UID))
		m.Event(EVENT_PLACE_REMOVE, args)
		m.ProcessRefresh().ToastSuccess()
	}
}

func init() { ice.Cmd(prefixKey(), portal{}) }

type Portal struct {
	portal
	export string `data:"true"`
	short  string `data:"index"`
	field  string `data:"time,name,icons,index,order,enable"`
}

func init() { ice.Cmd(prefixKey(), Portal{}) }

func (s portal) Show(m *ice.Message, arg ...string) {
	cmd := m.GetCommand()
	m.Cmd(s, s.Create, mdb.NAME, cmd.Help, mdb.ICONS, cmd.Icon, ctx.INDEX, m.PrefixKey())
}
